@@ -17,10 +17,28 @@ from pathlib import Path
 
 # Support downloading object under a different name
 class CloudStorage(list):
+    """A class for managing a group of files in Optumi cloud storage.
+
+    The class methods list() and find() produce a CloudStorage object that contain the requested list of files found in cloud
+        storage while the methods download() and remove() operate on the list of files contained in the CloudStorage object itself.
+    """
+
     def __init__(self, files: list = []):
+        """Constructor for an object that represents all files or a specific subset of files in cloud storage.
+
+        The CloudStorage object can perform "download", "remove", "list" and "find" operation on files of interest.
+
+        Args:
+            files (list of CloudFile, optional): List of CloudFile objects in cloud storage. Defaults to [] which refers to all files in cloud storage.
+        """
         super().__init__(files)
 
     def download(self, wait=True):
+        """Download the newest version of the list of files contained in the current CloudStorage object from Optumi cloud storage.
+
+        Args:
+            wait (bool, optional): A boolean indicating whether the download should wait for completion before returning. Defaults to True.
+        """
         if len(self) > 0:
             key = str(uuid4())
             print("Downloading", "files..." if len(self) > 1 else "file...")
@@ -45,6 +63,8 @@ class CloudStorage(list):
                 print("...completed")
 
     def remove(self):
+        """Remove all versions of the list of files contained in the current CloudStorage object from Optumi cloud storage."""
+
         if len(self) > 0:
             print("Removing", "files..." if len(self) > 1 else "file...")
             for f in self:
@@ -68,7 +88,12 @@ class CloudStorage(list):
             print("...completed")
 
     @classmethod
-    def list(self):
+    def list(cls):
+        """List all files in Optumi cloud storage.
+
+        Returns:
+            CloudStorage: A list of all CloudFile objects in cloud storage.
+        """
         res = optumi.core.list_files()
         response = json.loads(res.text)
         files = CloudStorage()
@@ -94,25 +119,22 @@ class CloudStorage(list):
         return files
 
     @classmethod
-    def find(self, match="", contains=""):
+    def find(cls, match="", contains=""):
+        """Find all files in Optumi cloud storage matching a given file name or containing a substring.
+
+        Args:
+            match (str, optional): File name to match. Defaults to "".
+            contains (str, optional): Substring to match anywhere in the file path. Defaults to "".
+
+        Returns:
+            CloudStorage: All matching files in the cloud.
+        """
         if match:
             return CloudStorage(
-                [
-                    x
-                    for x in CloudStorage.list()
-                    if optumi.utils.normalize_path(match, strict=False)
-                    == optumi.utils.normalize_path(x.path, strict=False)
-                ]
+                [x for x in CloudStorage.list() if optumi.utils.normalize_path(match, strict=False) == optumi.utils.normalize_path(x.path, strict=False)]
             )
         elif contains:
-            return CloudStorage(
-                [
-                    x
-                    for x in CloudStorage.list()
-                    if str(contains)
-                    in optumi.utils.normalize_path(x.path, strict=False)
-                ]
-            )
+            return CloudStorage([x for x in CloudStorage.list() if str(contains) in optumi.utils.normalize_path(x.path, strict=False)])
         else:
             return CloudStorage([])
 
