@@ -37,12 +37,7 @@ class Colab:
             resource = Server(size="Standard_NC4as_T4_v3")
 
         if progress != None and not progress in Workload.progress:
-            raise OptumiException(
-                "Unexpected progress '"
-                + progress
-                + "', expected on of "
-                + str(Workload.progress)
-            )
+            raise OptumiException("Unexpected progress '" + progress + "', expected one of " + str(Workload.progress))
 
         # Start with blank config
         nb_config = create_config()
@@ -58,10 +53,7 @@ class Colab:
 
         # Make sure files are uploaded
         files.upload()
-        nb_config["upload"]["files"] = [
-            {"path": optumi.utils.replace_home_with_tilde(path), "enabled": True}
-            for path in expanded
-        ]
+        nb_config["upload"]["files"] = [{"path": optumi.utils.replace_home_with_tilde(path), "enabled": True} for path in expanded]
 
         # Plug in environment variables
         if type(env) is EnvironmentVariables:
@@ -110,12 +102,7 @@ class Colab:
         notebook = _message.blocking_request("get_ipynb")["ipynb"]
 
         # Remove the optumi cell
-        notebook["cells"] = [
-            cell
-            for cell in notebook["cells"]
-            if cell["cell_type"] == "code"
-            and not "".join(cell["source"]).startswith("#skip@optumi")
-        ]
+        notebook["cells"] = [cell for cell in notebook["cells"] if cell["cell_type"] == "code" and not "".join(cell["source"]).startswith("#skip@optumi")]
 
         program = json.dumps(notebook)
 
@@ -145,18 +132,8 @@ class Colab:
 
         hashes = [optumi.utils.hash_file(f) for f in expanded]
         stats = [os.stat(f) if os.path.isfile(f) else None for f in expanded]
-        creation_times = [
-            datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z"
-            if stat != None
-            else None
-            for stat in stats
-        ]
-        last_modification_times = [
-            datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z"
-            if stat != None
-            else None
-            for stat in stats
-        ]
+        creation_times = [datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z" if stat != None else None for stat in stats]
+        last_modification_times = [datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z" if stat != None else None for stat in stats]
         sizes = [str(stat.st_size) if stat else None for stat in stats]
 
         optumi.core.launch_notebook(
@@ -174,13 +151,9 @@ class Colab:
 
         # print(launch_status)
 
-        module_uuid = (
-            launch_status["modules"][0] if "modules" in launch_status else None
-        )
+        module_uuid = launch_status["modules"][0] if "modules" in launch_status else None
 
-        workload = Workload(
-            name, program, workload_uuid, module_uuid, nb_config, run_num
-        )
+        workload = Workload(name, program, workload_uuid, module_uuid, nb_config, run_num)
         if wait:
             workload.wait(progress)
         return workload
