@@ -21,7 +21,18 @@ from typing import Union
 
 
 class Container:
+    """A class for managing containers."""
+
     def __init__(self, image: str, registry: ContainerRegistry = None):
+        """Constructor for a Container object taking a container image name and an optional container registry to pull from.
+
+        Args:
+            image (str): Container image name.
+            registry (ContainerRegistry, optional): Registry containing the image. Defaults to None.
+
+        Raises:
+            OptumiException: Raised if an invalid container name is specified.
+        """
         if not bool(re.match("^[a-zA-Z0-9][a-zA-Z0-9/_.-]+$", image)):
             raise OptumiException("Invalid container name '" + image + "'")
         self._image = image
@@ -39,18 +50,26 @@ class Container:
         resource=None,
         notifications=None,
     ):
+        """Launch a container given a specific configuration.
+
+        Args:
+            wait (bool): Whether or not to wait for the workload to finish execution before returning. Defaults to True.
+            progress (str): How much progress data to return with the launched workload. Can be one of "silent", "summary", "detail". Defaults to "summary".
+            env (Union[EnvironmentVariables, list]): Environment variables to provision before running the container.
+            args ([str]): Command-line arguments to provide when running the container.
+            resource (Resource): Resource requirements for the server that will be running the container. Defaults to None.
+            notifications (Notification): User notification options when running the container. Defaults to None.
+
+        Returns:
+            Workload: A workload representing the container.
+        """
         if resource is None:
             resource = Server(size="Standard_NC4as_T4_v3")
 
         if progress != None and not progress in Workload.progress:
-            raise OptumiException(
-                "Unexpected progress '"
-                + progress
-                + "', expected on of "
-                + str(Workload.progress)
-            )
+            raise OptumiException("Unexpected progress '" + progress + "', expected one of " + str(Workload.progress))
 
-        # Start with blank config
+        # Start with blank configuration
         nb_config = create_config()
 
         # Plug in program type
@@ -133,8 +152,6 @@ class Container:
 
         # print(setup)
 
-        # TODO:JJ What do we do about error handling for these calls
-
         workload_uuid = setup["uuid"]
         run_num = setup["runNum"]
 
@@ -157,9 +174,7 @@ class Container:
 
         # print(launch_status)
 
-        module_uuid = (
-            launch_status["modules"][0] if "modules" in launch_status else None
-        )
+        module_uuid = launch_status["modules"][0] if "modules" in launch_status else None
 
         workload = Workload(
             container_name,
@@ -176,10 +191,20 @@ class Container:
 
     @property
     def image(self):
+        """Obtain the container image name.
+
+        Returns:
+            str: The container image name.
+        """
         return self._image
 
     @property
     def registry(self):
+        """Obtain the container registry.
+
+        Returns:
+            ContainerRegistry: The container registry.
+        """
         return self._registry
 
     def __str__(self):
