@@ -24,17 +24,23 @@ from typing import Union
 
 
 class Executable:
+    """A class for defining an executable program with optional environment and resource requirements."""
+
     program_types = ["python notebook", "python script", "docker container", "unknown"]
 
     def __init__(self, path: str, program_type="unknown"):
+        """Constructor specifying a file path to the program and the type of the program.
+
+        Args:
+            path (str): the local path to the program
+            program_type (str, optional): The type of the program. One of "python notebook", "python script", "docker container" or "unknown". Defaults to "unknown".
+
+        Raises:
+            OptumiException: Raised if the program type is not specified properly.
+        """
         self._path = optumi.utils.normalize_path(path)
         if not program_type in Executable.program_types:
-            raise OptumiException(
-                "Unexpected program type '"
-                + program_type
-                + "', expected on of "
-                + str(program_types)
-            )
+            raise OptumiException("Unexpected program type '" + program_type + "', expected one of " + str(program_types))
         self._program_type = program_type
 
     def __utcnow(self):
@@ -51,16 +57,29 @@ class Executable:
         notifications=None,
         interactive=False,
     ):
+        """Launch an executable given a specific configuration.
+
+        Args:
+            wait (bool): Whether or not to wait for the workload to finish execution before returning. Defaults to True.
+            progress (str): How much progress data to return with the launched workload. Can be one of "silent", "summary", "detail". Defaults to 'summary'.
+            env (Union[EnvironmentVariables, list]): Environment variables to configure before running the program.
+            packages (Packages, optional):  Python packages required for executing the program. Defaults to empty.
+            files (LocalStorage, optional): Any input files needed for the program's execution. Defaults to empty.
+            resource (Server, Resource, optional): Server or Resource requirements for running the program. Defaults to None (meaning a GPU machine will be used).
+            notifications (Notification): User notification options when running the container. Defaults to None.
+            interactive (bool, optional): Wether to run the program as an interactive session. Defaults to False.
+
+        Raises:
+            OptumiException: Raised if any of the requirements are specified incorrectly.
+
+        Returns:
+            Workload: A workload representing the program.
+        """
         if resource is None:
             resource = Server(size="Standard_NC4as_T4_v3")
 
         if progress != None and not progress in Workload.progress:
-            raise OptumiException(
-                "Unexpected progress '"
-                + progress
-                + "', expected on of "
-                + str(Workload.progress)
-            )
+            raise OptumiException("Unexpected progress '" + progress + "', expected one of " + str(Workload.progress))
 
         # Start with blank config
         nb_config = create_config()
@@ -79,10 +98,7 @@ class Executable:
 
         # Make sure files are uploaded
         files.upload()
-        nb_config["upload"]["files"] = [
-            {"path": optumi.utils.replace_home_with_tilde(path), "enabled": True}
-            for path in expanded
-        ]
+        nb_config["upload"]["files"] = [{"path": optumi.utils.replace_home_with_tilde(path), "enabled": True} for path in expanded]
 
         # Register any unsaved environment variables with the controller
         # Plug in environment variables
@@ -152,18 +168,8 @@ class Executable:
 
         hashes = [optumi.utils.hash_file(f) for f in expanded]
         stats = [os.stat(f) if os.path.isfile(f) else None for f in expanded]
-        creation_times = [
-            datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z"
-            if stat != None
-            else None
-            for stat in stats
-        ]
-        last_modification_times = [
-            datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z"
-            if stat != None
-            else None
-            for stat in stats
-        ]
+        creation_times = [datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z" if stat != None else None for stat in stats]
+        last_modification_times = [datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z" if stat != None else None for stat in stats]
         sizes = [str(stat.st_size) if stat else None for stat in stats]
 
         try:
@@ -185,9 +191,7 @@ class Executable:
 
         # print(launch_status)
 
-        module_uuid = (
-            launch_status["modules"][0] if "modules" in launch_status else None
-        )
+        module_uuid = launch_status["modules"][0] if "modules" in launch_status else None
 
         workload = Workload(
             optumi.utils.replace_home_with_tilde(self._path),
@@ -203,6 +207,11 @@ class Executable:
 
     @property
     def path(self):
+        """Obtain the file path of the executable.
+
+        Returns:
+            str: The file path of the executable program.
+        """
         return self._path
 
     def __str__(self):
