@@ -19,7 +19,14 @@ STORAGE_LIMIT = 1024 * 1024 * 1024 * 1024  # Assume the largest storage total
 
 
 class LocalStorage(list):
+    """A class for uploading files to Optumi cloud storage."""
+
     def __init__(self, files: Union[list, str] = []):
+        """Constructor for a LocalStorage object.
+
+        Args:
+            files (list of LocalFile, optional): List of local files, useful for performing batch uploads. Defaults to [].
+        """
         _files = []
         if type(files) is str:
             _files.append(LocalFile(files))
@@ -34,6 +41,11 @@ class LocalStorage(list):
         super().__init__(_files)
 
     def upload(self, wait=True):
+        """Upload the list of local files to Optumi cloud storage.
+
+        Args:
+            wait (bool, optional): Upload the local version of a file to cloud storage. If 'wait' is True, it will wait until the download is complete before returning. Defaults to True.
+        """
         if len(self) > 0:
             key = str(uuid4())
             print("Uploading", "files..." if len(self) > 1 else "file...")
