@@ -17,15 +17,23 @@ from optumi_core.exceptions import (
 
 
 class Machines:
+    """A class for retrieving a list of dynamically allocated machines."""
+
     @classmethod
     def list(cls, status: str = None):
+        """Obtain a list of all allocated machines optionally matching a given status.
+
+        Args:
+            status (str, optional): The status of the machine to match as one of "Acquiring", "Configuring", "Busy", "Idle", "Releasing". Defaults to None.
+
+        Raises:
+            OptumiException: Raised if an unrecognized status is provided.
+
+        Returns:
+            list of machines: A list of Machine objects matching any given status.
+        """
         if status != None and not status in Machine.status_values:
-            raise OptumiException(
-                "Unexpected machine status '"
-                + status
-                + "', expected on of "
-                + str(Machine.status_values)
-            )
+            raise OptumiException("Unexpected machine status '" + status + "', expected one of " + str(Machine.status_values))
 
         machines = []
 
