@@ -9,7 +9,14 @@ from .Executable import *
 
 
 class Notebook(Executable):
+    """A class for executing Python notebooks. Extends Executable."""
+
     def __init__(self, path: str):
+        """Constructor for the Notebook object.
+
+        Args:
+            path (str): The file path to the notebook to be executed.
+        """
         super().__init__(path, "python notebook")
 
     def __str__(self):
