@@ -9,7 +9,14 @@ from .Executable import *
 
 
 class Script(Executable):
+    """A class for executing Python scripts. Extends Executable."""
+
     def __init__(self, path: str):
+        """Constructor for a Script object.
+
+        Args:
+            path (str): The file path to the script.
+        """
         super().__init__(path, "python script")
 
     def __str__(self):
