@@ -17,6 +17,8 @@ class ProgressMessage:
 
 
 class Summary:
+    """An internal helper class for obtaining a workload summary."""
+
     def __init__(
         self,
         name: str,
@@ -24,23 +26,28 @@ class Summary:
         preparing_lines: list,
         running_lines: list,
     ):
+        """Internal constructor for a Summary object.
+
+        Args:
+            name (str): the name that will be used to create the summary file.
+            initializing_lines (list): The summary lines
+            preparing_lines (list): The preparing lines
+            running_lines (list): The running lines
+        """
         self._name = name
         self._initializing_lines = initializing_lines
         self._preparing_lines = preparing_lines
         self._running_lines = running_lines
 
     def download(self, path: str = None):
-        f_name = optumi.utils.normalize_path(
-            self._name.split("/")[-1] + ".summary" if path is None else path, False
-        )
+        """Download the workload summary to the given file path.
+
+        Args:
+            path (str, optional): The file path where the summary should be stored. If not provided, the summary will be created in the current working directory under the filename specified during initialization. Defaults to None.
+        """
+        f_name = optumi.utils.normalize_path(self._name.split("/")[-1] + ".summary" if path is None else path, False)
         with open(f_name, "w+") as f:
-            f.write(
-                collapseUpdates(
-                    self._initializing_lines
-                    + self._preparing_lines
-                    + self._running_lines
-                )
-            )
+            f.write(collapseUpdates(self._initializing_lines + self._preparing_lines + self._running_lines))
         print("Summary saved to " + f_name)
 
     def __str__(self):
