@@ -21,10 +21,25 @@ from sys import exit
 
 
 class Workload:
+    """A class representing an individual workload.
+
+    This class contains information about program execution including logs, run numbers and input/output files.
+    """
+
     status_values = ["queued", "launching", "running", "completed"]
     progress = ["silent", "summary", "detail"]  # add "status" later
 
     def __init__(self, path, program, workload_uuid, module_uuid, config, run_num):
+        """Constructor for a Workload object.
+
+        Args:
+            path (str): The file path of the workload.
+            program (Program): Program object associated with this workload.
+            workload_uuid (str): Unique identifier for the workload.
+            module_uuid (str): Unique identifier for the module.
+            config (dict): Dictionary containing configuration related to this workload.
+            run_num (int): Numerical value corresponding to which run of the given program this workload represents.
+        """
         self._path = path
         self._program = program
 
@@ -60,22 +75,16 @@ class Workload:
 
         if "initializing" in workload and workload["initializing"] != None:
             for i in range(len(workload["initializing"])):
-                self._initializing_lines.append(
-                    (workload["initializing"][i], workload["initializingmod"][i])
-                )
+                self._initializing_lines.append((workload["initializing"][i], workload["initializingmod"][i]))
 
         if "preparing" in workload and workload["preparing"] != None:
             for i in range(len(workload["preparing"])):
-                self._preparing_lines.append(
-                    (workload["preparing"][i], workload["preparingmod"][i])
-                )
+                self._preparing_lines.append((workload["preparing"][i], workload["preparingmod"][i]))
                 updates_to_print.append(self._preparing_lines[-1])
 
         if "running" in workload and workload["running"] != None:
             for i in range(len(workload["running"])):
-                self._running_lines.append(
-                    (workload["running"][i], workload["runningmod"][i])
-                )
+                self._running_lines.append((workload["running"][i], workload["runningmod"][i]))
                 updates_to_print.append(self._running_lines[-1])
 
         if "files" in workload and workload["files"] != None:
@@ -116,9 +125,7 @@ class Workload:
 
         if "updates" in module and module["updates"] != None:
             for i in range(len(module["updates"])):
-                self._update_lines.append(
-                    (module["updates"][i], module["updatesmod"][i])
-                )
+                self._update_lines.append((module["updates"][i], module["updatesmod"][i]))
 
         if "files" in module and module["files"] != None:
             self._output_files = CloudStorage(
@@ -141,9 +148,7 @@ class Workload:
 
         if "monitoring" in module and module["monitoring"] != None:
             for i in range(len(module["monitoring"])):
-                self._monitoring.append(
-                    (module["monitoring"][i], module["monitoringmod"][i])
-                )
+                self._monitoring.append((module["monitoring"][i], module["monitoringmod"][i]))
 
         if "patches" in module and module["patches"] != None:
             self._num_patches = len(module["patches"])
@@ -166,7 +171,7 @@ class Workload:
             None,
             workload["uuid"],
             workload["modules"][0]["uuid"] if len(workload["modules"]) > 0 else None,
-            workload["nbConfig"],
+            json.loads(workload["nbConfig"]),
             workload["runNum"],
         )
 
@@ -204,17 +209,10 @@ class Workload:
 
     def __print_updates(self, progress, updates_to_print):
         for update in updates_to_print:
-            if (
-                re.sub("[^a-zA-Z]", "", update[0]) != ""
-                and update[0] != "\n"
-                and update[0] != "stop"
-                and update[0] != "error"
-            ):
+            if re.sub("[^a-zA-Z]", "", update[0]) != "" and update[0] != "\n" and update[0] != "stop" and update[0] != "error":
                 if progress == "summary":
                     print(
-                        update[0]
-                        if update[0].endswith("\n")
-                        else self.__adjust_message(update[0]) + "\n",
+                        update[0] if update[0].endswith("\n") else self.__adjust_message(update[0]) + "\n",
                         end="",
                         flush=True,
                     )
@@ -222,6 +220,11 @@ class Workload:
                 #     self.__print_status()
 
     def wait(self, progress="summary"):
+        """Wait for a workload to complete by regularly checking the workload status.
+
+        Args:
+            progress (str, optional): Defines the level of verbosity in reporting the workload statusas as one of "summary", "detail" or "silent". Defaults to "summary".
+        """
         self._last_line_length = 0
 
         self.__print_output(progress, self._output)
@@ -261,12 +264,7 @@ class Workload:
 
                 # If we set the token, print the link for the user to access his session and stop waiting
                 if token == None and self._token != None:
-                    print(
-                        "Session available at: https://"
-                        + self._machine.dns_name
-                        + ":54321/?token="
-                        + self._token
-                    )
+                    print("Session available at: https://" + self._machine.dns_name + ":54321/?token=" + self._token)
                     return
 
             if self.__get_status() == "completed":
@@ -278,12 +276,14 @@ class Workload:
         #     print()
 
     def stop(self, wait=True):
+        """Stop the current workload.
+
+        Args:
+            wait (bool, optional): If set to True, the function will wait till the workload has been terminated before returning. Defaults to True.
+        """
         from .Workloads import Workloads
 
-        if (
-            optumi.login.is_dynamic()
-            and Workloads.current()._workload_uuid == self._workload_uuid
-        ):
+        if optumi.utils.is_dynamic() and Workloads.current()._workload_uuid == self._workload_uuid:
             print("Stopping current workload")
             # This is for sessions
             code = os.system("jupyter lab stop 54321")
@@ -293,25 +293,26 @@ class Workload:
         else:
             print("Stopping workload " + self.name + "...")
             if self.status != "completed":
-                optumi.core.stop_notebook(
-                    self._workload_uuid, None
-                )  # Remove the second argument when we move to 3.14
+                optumi.core.stop_notebook(self._workload_uuid)
                 if wait and self.status == "running":
                     self.wait(progress="silent")
             print("...completed")
 
     def remove(self, wait=True):
-        # TODO: Add an override flag to stop workload before removing
+        """Remove the current workload."""
         if self.status != "completed":
-            self.stop()
+            self.stop(wait)
         print("Removing workload " + self.name + "...")
-        optumi.core.teardown_notebook(
-            self._workload_uuid, None
-        )  # Remove the second argument when we move to 3.14
+        optumi.core.teardown_notebook(self._workload_uuid)
         print("...completed")
 
     @property
     def status(self):
+        """Obtain the current status of the workload.
+
+        Returns:
+            str: The current status of the workload as "launching", "running" or "completed".
+        """
         self._refresh()
         return self.__get_status()
 
@@ -346,11 +347,7 @@ class Workload:
 
     def __adjust_message(self, message):
         # We will say a session is starting until we can connect to it
-        if (
-            self._nb_config["interactive"]
-            and message == "Running"
-            and self._token == None
-        ):
+        if self._nb_config["interactive"] and message == "Running" and self._token == None:
             return "Connecting"
         # We call a running app 'Connected'
         if self._nb_config["interactive"] and message == "Running":
@@ -366,6 +363,11 @@ class Workload:
 
     @property
     def detailed_status(self):
+        """Obtain the detailed status of this workload.
+
+        Returns:
+            str: The detailed status of this workload.
+        """
         self._refresh()
 
         message = ""
@@ -426,31 +428,30 @@ class Workload:
         for update in reversed(updates):
             line = update[0]
             modifier = update[1]
-            if (
-                line != "error"
-                and line != "stop"
-                and line != ""
-                and not modifier.startswith("{")
-            ):
+            if line != "error" and line != "stop" and line != "" and not modifier.startswith("{"):
                 return line
         return ""
 
     @property
     def log(self):
+        """Obtain the log.
+
+        Returns:
+            Log: the log
+        """
         self._refresh()
         if len(self._output) == 0:
-            for workload in json.loads(
-                optumi.core.get_workload_properties(
-                    self._workload_uuid, [], ["output"]
-                ).text
-            )["jobs"]:
-                self._handle_workload_update(
-                    workload
-                )  # There will only be one job returned and it will be the correct one
+            for workload in json.loads(optumi.core.get_workload_properties(self._workload_uuid, [], ["output"]).text)["jobs"]:
+                self._handle_workload_update(workload)  # There will only be one job returned and it will be the correct one
         return Log(self._path, self._output)
 
     @property
     def summary(self):
+        """Obtain the workload summary.
+
+        Returns:
+            Summary: The status summary of this workload.
+        """
         self._refresh()
         return Summary(
             self._path,
@@ -461,47 +462,65 @@ class Workload:
 
     @property
     def program(self):
+        """Obtain the program.
+
+        Returns:
+            Program: The program represented by this workload.
+        """
         self._refresh()
         if self._program == None:
-            for workload in json.loads(
-                optumi.core.get_workload_properties(
-                    self._workload_uuid, [], ["notebook"]
-                ).text
-            )["jobs"]:
-                self._handle_workload_update(
-                    workload
-                )  # There will only be one job returned and it will be the correct one
+            for workload in json.loads(optumi.core.get_workload_properties(self._workload_uuid, [], ["notebook"]).text)["jobs"]:
+                self._handle_workload_update(workload)  # There will only be one job returned and it will be the correct one
         return Program(self._path, self._run_num, self._program)
 
     @property
     def input_files(self):
+        """Obtain the input files specified for this workload.
+
+        Returns:
+            CloudStorage: The list of input files in Optumi cloud storage.
+        """
         self._refresh()
         return self._input_files
 
     @property
     def output_files(self):
+        """Obtain the output files generatd by this workload.
+
+        Returns:
+            CloudStorage: The list of output files in Optumi cloud storage.
+        """
         self._refresh()
         if self._program == None:
-            for workload in json.loads(
-                optumi.core.get_workload_properties(
-                    self._workload_uuid, [], ["files"]
-                ).text
-            )["jobs"]:
-                self._handle_workload_update(
-                    workload
-                )  # There will only be one job returned and it will be the correct one
+            for workload in json.loads(optumi.core.get_workload_properties(self._workload_uuid, [], ["files"]).text)["jobs"]:
+                self._handle_workload_update(workload)  # There will only be one job returned and it will be the correct one
         return self._output_files
 
     @property
     def name(self):
+        """Obtain the name of this workload.
+
+        Returns:
+            str: The composed name of the workload containing the assigned name and the run number.
+        """
         return self._path.split("/")[-1] + " (Run #" + str(self._run_num) + ")"
 
     @property
     def path(self):
+        """Obtain the pathname of this workload.
+
+        Returns:
+            str: The pathname of the workload.
+        """
         return optumi.utils.normalize_path(self._path, strict=False)
 
     @property
     def machine(self):
+        """Obtain the machine this workload is or was running on.
+
+        Returns:
+            Machine: The Machine object representing the machine that the workload is or was running on.
+        """
         return self._machine
 
     def __str__(self):
